@@ -15,11 +15,11 @@ from . import errors
 from . import parsers
 from . import types
 
-__version__ = "0.2.1"
+__version__ = "0.3.2"
 
 
 def sam(
-    body: Optional[Union[bool,Callable]] = parsers.parse_json,
+    body: Optional[Union[bool,Callable]] = json.loads,
     pathParams: Optional[Union[bool,Callable]] = False,
     queryString: Optional[Union[bool,Callable]] = False,
     headers: Optional[Union[bool,Callable]] = False,
@@ -169,7 +169,7 @@ def sam(
             except errors.HttpError as e:
                 return e.json()
             except Exception as e:
-                print("UNCAUGHT ERROR:", e)
+                print(f"UNCAUGHT ERROR: \"{e}\"")
                 return errors.InternalServerError().json()
 
             # Return a response
